Changelog
=========

0.2.1
-----
    - Fixed bug in build system.

0.2.0
-----
    - Added docstrings.
    - Added integration tests.
    - Added `sphinx documentation <http://cz-urnnbn-api.readthedocs.org/`_, README.

0.1.0
-----
    - Project created.
